@@ -7,6 +7,7 @@ from Bio import SeqIO, SeqFeature
 from Bio.SeqRecord import SeqRecord
 import pandas as pd
 pd.options.mode.chained_assignment = None
+import math
 import numpy as np
 import warnings
 import time
@@ -33,10 +34,14 @@ def cluster_DBSCAN(jac_dist, table_output_suffix, min_group_size):
 	# cluster and extract cluster label assignments
 
 	if min_group_size == 'default':
-		min_group_size = np.log(len(jac_dist))
+		min_group_size = math.floor(np.log(len(jac_dist)))
 	else:
 		min_group_size = int(min_group_size)
 
+	if min_group_size < 2:
+		print('Minimum group size is < 2 -- will change minimum group size to 2')
+		min_group_size = 2
+
 	print('Using a minimum group size of {}'.format(min_group_size))
 
 	cluster_label_assignments = {}
